@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: clock
-version: 0.7.1.1
-id: clock-0.7.1.1-48205698dc759abc70fe01a1aa47cc9f
-key: clock_8pKQ8uZrT9tBSgyVrIbiAM
+version: 0.7.2
+id: clock-0.7.2-d9df232649dd50ab099f24881122ce3e
+key: clock_25jKxsKUfKCI5az98RdfRZ
 license: BSD3
-copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015
+copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015, Mario Longobardi 2016
 maintainer: Cetin Sert <cetin@corsis.eu>, Corsis Research
 stability: stable
 homepage: https://github.com/corsis/clock
@@ -40,6 +40,8 @@ description:
     .
     Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.
     .
+    Fixes for older Linux build failures introduced by new Linux-specific clocks by Mario Longobardi on 2016-04-18.
+    .
     [Version Scheme]
     Major-@/R/@-ewrite . New-@/F/@-unctionality . @/I/@-mprovementAndBugFixes . @/P/@-ackagingOnly
     .
@@ -50,10 +52,10 @@ exposed: True
 exposed-modules:
     System.Clock
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/clock-0.7.1.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/clock-0.7.1.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/clock-0.7.1.1
-hs-libraries: HSclock-0.7.1.1-8pKQ8uZrT9tBSgyVrIbiAM
+import-dirs: /usr/lib/ghc-7.10.3/site-local/clock-0.7.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/clock-0.7.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/clock-0.7.2
+hs-libraries: HSclock-0.7.2-25jKxsKUfKCI5az98RdfRZ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
 haddock-interfaces: /usr/share/doc/haskell-clock/html/clock.haddock
